@@ -4,7 +4,10 @@ use strict;
 use warnings;
 use 5.010;
 
-use JIRA::REST::Class::Version qw( $VERSION );
+our $VERSION = '0.06';
+our $SOURCE = 'CPAN';
+## $SOURCE = 'GitHub';  # COMMENT
+# the line above will be commented out by Dist::Zilla
 
 # ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents an individual change to a JIRA issue as an object.
 
@@ -66,7 +69,7 @@ JIRA::REST::Class::Issue::Changelog::Change - A helper class for L<JIRA::REST::C
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 READ-ONLY ACCESSORS
 
@@ -102,8 +105,6 @@ objects.
 
 =item * L<JIRA::REST::Class::User|JIRA::REST::Class::User>
 
-=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
-
 =back
 
 =head1 AUTHOR
@@ -112,7 +113,7 @@ Packy Anderson <packy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Packy Anderson.
+This software is Copyright (c) 2017 by Packy Anderson.
 
 This is free software, licensed under:
 
