@@ -4,7 +4,10 @@ use strict;
 use warnings;
 use 5.010;
 
-use JIRA::REST::Class::Version qw( $VERSION );
+our $VERSION = '0.06';
+our $SOURCE = 'CPAN';
+## $SOURCE = 'GitHub';  # COMMENT
+# the line above will be commented out by Dist::Zilla
 
 # ABSTRACT: A helper class for L<JIRA::REST::Class|JIRA::REST::Class> that represents a component of a JIRA project as an object.
 
@@ -46,7 +49,7 @@ JIRA::REST::Class::Project::Component - A helper class for L<JIRA::REST::Class|J
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 READ-ONLY ACCESSORS
 
@@ -74,8 +77,6 @@ Returns the JIRA REST API URL of the project category.
 
 =item * L<JIRA::REST::Class::Abstract|JIRA::REST::Class::Abstract>
 
-=item * L<JIRA::REST::Class::Version|JIRA::REST::Class::Version>
-
 =back
 
 =head1 AUTHOR
@@ -84,7 +85,7 @@ Packy Anderson <packy@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Packy Anderson.
+This software is Copyright (c) 2017 by Packy Anderson.
 
 This is free software, licensed under:
 
